@@ -17,7 +17,7 @@
 
 """GTK user interface for the Gaupol subtitle editor."""
 
-__version__ = "1.8"
+__version__ = "1.10.1"
 COMBO_SEPARATOR = "<separator/>"
 
 import sys
@@ -28,6 +28,12 @@ if hasattr(sys, "frozen"):
     # https://stackoverflow.com/a/35773092
     warnings.simplefilter("ignore")
 
+# Needed for the spell-check dialog, where the '_proceed' function call is
+# recursive. The recursion limit effectively defines the maximum allowed
+# amount of consecutive subtitles without spelling errors, which if exceeded
+# triggers a RecursionError.
+sys.setrecursionlimit(10000)
+
 import aeidon
 import gi
 import os
@@ -44,6 +50,7 @@ for module, version in {
     "Gst": "1.0",
     "GstPbutils": "1.0",
     "GstVideo": "1.0",
+    "GstTag": "1.0",
 }.items():
     with aeidon.util.silent(Exception):
         gi.require_version(module, version)
