@@ -19,6 +19,7 @@ import aeidon
 import gaupol
 
 from gi.repository import Gtk
+from unittest.mock import patch
 
 from gaupol.assistants import CapitalizationPage
 from gaupol.assistants import CommonErrorPage
@@ -30,6 +31,8 @@ from gaupol.assistants import LineBreakOptionsPage
 from gaupol.assistants import LineBreakPage
 from gaupol.assistants import ProgressPage
 
+OK = lambda *args: Gtk.ResponseType.OK
+
 
 class _TestBuilderPage(gaupol.TestCase):
 
@@ -104,7 +107,10 @@ class TestJoinSplitWordsPage(_TestBuilderPage):
         self.window.add(self.page)
         self.window.show_all()
 
+    @patch("gaupol.util.flash_dialog", OK)
     def test_correct_texts(self):
+        language = self.get_spell_check_language("en")
+        gaupol.conf.spell_check.language = language
         self.page.correct_texts(self.project,
                                 None,
                                 aeidon.documents.MAIN)
